==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/drafts/com/sun/star/form/ListEntryEvent.hpp <==
#ifndef _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_
#define _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HDL_
#include "drafts/com/sun/star/form/ListEntryEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace drafts { namespace com { namespace sun { namespace star { namespace form {

inline ListEntryEvent::ListEntryEvent() SAL_THROW( () )
    : ::com::sun::star::lang::EventObject()
    , Position(0)
    , Count(0)
    , Entries()
{
}

inline ListEntryEvent::ListEntryEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::sal_Int32& Position_, const ::sal_Int32& Count_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& Entries_) SAL_THROW( () )
    : ::com::sun::star::lang::EventObject(Source_)
    , Position(Position_)
    , Count(Count_)
    , Entries(Entries_)
{
}

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::drafts::com::sun::star::form::ListEntryEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "drafts.com.sun.star.form.ListEntryEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/drafts/com/sun/star/form/ListEntryEvent.hpp <==
#ifndef _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_
#define _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HDL_
#include "drafts/com/sun/star/form/ListEntryEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace drafts { namespace com { namespace sun { namespace star { namespace form {

inline ListEntryEvent::ListEntryEvent() SAL_THROW( () )
    : ::com::sun::star::lang::EventObject()
    , Position(0)
    , Count(0)
    , Entries()
{
}

inline ListEntryEvent::ListEntryEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::sal_Int32& Position_, const ::sal_Int32& Count_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& Entries_) SAL_THROW( () )
    : ::com::sun::star::lang::EventObject(Source_)
    , Position(Position_)
    , Count(Count_)
    , Entries(Entries_)
{
}

} } } } }

namespace drafts { namespace com { namespace sun { namespace star { namespace form {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::drafts::com::sun::star::form::ListEntryEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "drafts.com.sun.star.form.ListEntryEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::drafts::com::sun::star::form::ListEntryEvent const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::drafts::com::sun::star::form::ListEntryEvent >::get();
}

#endif // _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_
